@@ -16,20 +16,19 @@
 
 # XEP-0384: OMEMO Encryption
 
-import os
 import time
 from pathlib import Path
 
-import nbxmpp
 from nbxmpp.namespaces import Namespace
 from nbxmpp.protocol import NodeProcessed
 from nbxmpp.protocol import JID
-from nbxmpp.util import is_error_result
+from nbxmpp.errors import StanzaError
 from nbxmpp.const import PresenceType
 from nbxmpp.const import Affiliation
 from nbxmpp.structs import StanzaHandler
 from nbxmpp.modules.omemo import create_omemo_message
 from nbxmpp.modules.omemo import get_key_transport_message
+from nbxmpp.modules.util import is_error
 
 from gajim.common import app
 from gajim.common import configpaths
@@ -38,6 +37,7 @@ from gajim.common.const import EncryptionData
 from gajim.common.const import Trust as GajimTrust
 from gajim.common.modules.base import BaseModule
 from gajim.common.modules.util import event_node
+from gajim.common.modules.util import as_task
 
 from gajim.plugins.plugins_i18n import _
 
@@ -58,6 +58,7 @@ ALLOWED_TAGS = [
     ('inactive', Namespace.CHATSTATES),
     ('paused', Namespace.CHATSTATES),
     ('composing', Namespace.CHATSTATES),
+    ('markable', Namespace.CHATMARKERS),
     ('no-store', Namespace.HINTS),
     ('store', Namespace.HINTS),
     ('no-copy', Namespace.HINTS),
@@ -320,9 +321,12 @@ class OMEMO(BaseModule):
                 callback=self._on_affiliations_received,
                 user_data=room_jid)
 
-    def _on_affiliations_received(self, result, room_jid):
-        if is_error_result(result):
-            self._log.info('Affiliation request failed: %s', result)
+    def _on_affiliations_received(self, task):
+        room_jid = task.get_user_data()
+        try:
+            result = task.finish()
+        except StanzaError as error:
+            self._log.info('Affiliation request failed: %s', error)
             return
 
         for user_jid in result.users:
@@ -351,7 +355,7 @@ class OMEMO(BaseModule):
             self.get_affiliation_list(event.room_jid)
 
     def _check_if_omemo_capable(self, jid):
-        disco_info = app.logger.get_last_disco_info(jid)
+        disco_info = app.storage.cache.get_last_disco_info(jid)
         if disco_info.muc_is_members_only and disco_info.muc_is_nonanonymous:
             self._log.info('OMEMO room discovered: %s', jid)
             self._omemo_groupchats.add(jid)
@@ -414,18 +418,17 @@ class OMEMO(BaseModule):
         self._nbxmpp('OMEMO').set_bundle(self.backend.bundle,
                                          self.backend.own_device)
 
+    @as_task
     def request_bundle(self, jid, device_id):
+        _task = yield
+
         self._log.info('Fetch device bundle %s %s', device_id, jid)
 
-        self._nbxmpp('OMEMO').request_bundle(
+        bundle = yield self._nbxmpp('OMEMO').request_bundle(
             jid,
-            device_id,
-            callback=self._bundle_received,
-            user_data=(jid, device_id))
+            device_id)
 
-    def _bundle_received(self, bundle, user_data):
-        jid, device_id = user_data
-        if is_error_result(bundle):
+        if is_error(bundle) or bundle is None:
             self._log.info('Bundle request failed: %s %s: %s',
                            jid, device_id, bundle)
             return
@@ -454,21 +457,20 @@ class OMEMO(BaseModule):
         self.backend.update_devicelist(self._own_jid, [self.backend.own_device])
         self.set_devicelist()
 
+    @as_task
     def request_devicelist(self, jid=None):
+        _task = yield
+
         if jid is None:
             jid = self._own_jid
 
         if jid in self._query_for_devicelists:
             return
 
-        self._nbxmpp('OMEMO').request_devicelist(
-            jid,
-            callback=self._devicelist_received,
-            user_data=jid)
         self._query_for_devicelists.append(jid)
 
-    def _devicelist_received(self, devicelist, jid):
-        if is_error_result(devicelist):
+        devicelist = yield self._nbxmpp('OMEMO').request_devicelist(jid=jid)
+        if is_error(devicelist) or devicelist is None:
             self._log.info('Devicelist request failed: %s %s', jid, devicelist)
             devicelist = []
 
